# eprint

Enhanched print() for Python

## How to install

```sh
pip install eprint
```
## How to use

```python
from eprint import eprint


eprint("Looks cool?")
eprint.ok("Success")
eprint.error("Failed")
eprint.ok("Use color for {} that need {} ", "values", "attention")
```